Error

Enum Error 

pub enum Error {
Show 25 variants Tokenizer { representation: String, source: Box<dyn Error>, }, ParserExpected { rule_fn: String, expecting: String, }, ParserUnexpected { rule_fn: String, given: String, expecting: Vec<String>, }, ParserUnreachable { rule_fn: String, given: String, }, InvalidFromStr { value: String, name: String, }, InvalidLiteralTypeCooercion { from_type: String, to_type: String, }, HexDecoder { value: String, index: usize, }, InvalidBlankNodeName { name: String, }, EmptyQName, InvalidQName { name: String, }, ProviderMismatch { lhs: String, rhs: String, }, InvalidMatch, AbsoluteIriExpected { uri: String, }, InvalidState, RdfStarNotSupported { representation: String, }, FormulaeNotSupported { representation: String, }, QueryResultsFormat { representation: String, }, Borrow(BorrowError), Io(Error), Iri(Error), LanguageTag(ParseError), Name(NameParseError), Utf8(FromUtf8Error), Base64Decoder(DecodeError), Unknown(String),
}
The Error type for this crate.

Variants



Tokenizer

This signals a parser tokenizer error.

Fields

representation: String
source: Box<dyn Error>


ParserExpected

This signals a parser error where some expected value was not found.

Fields

rule_fn: String
expecting: String


ParserUnexpected

This signals a parser error where some unexpected value was not found.

Fields

rule_fn: String
given: String
expecting: Vec<String>


ParserUnreachable

Fields

rule_fn: String
given: String


InvalidFromStr

The String value provided is not a valid value for it’s type.

Fields

value: String
name: String


InvalidLiteralTypeCooercion

Could not coerce from from_type to to_type.

Fields

from_type: String
to_type: String


HexDecoder

Could not decode a supposedly hex-encoded string.

Fields

value: String
index: usize


InvalidBlankNodeName

The String value provided is not a valid Blank Node name.

Fields

name: String


EmptyQName

A QName may not have an empty name part.



InvalidQName

The String value provided is not a valid QName.

Fields

name: String


ProviderMismatch

Values from these different providers cannot be combined.

Fields



InvalidMatch

The match combination is not valid.



AbsoluteIriExpected

An Absolute IRI was expected.

Fields



InvalidState

Some model element was in an invalid state for the requested operation.



RdfStarNotSupported

Statements as objects, from RDF*, are not supported by this representation.

Fields

representation: String


FormulaeNotSupported

Cited model.formulae, from N3, are not supported by this representation.

Fields

representation: String


QueryResultsFormat

Could not read or write query results in this representation.

Fields

representation: String


Borrow(BorrowError)

An error occurred borrowing from a standard cell type.



Io(Error)

An error in the standard I/O library.



Iri(Error)

An error parsing IRI strings.



LanguageTag(ParseError)

An eror parsing language-tag strings.



Name(NameParseError)

An error parsing Name strings.



Utf8(FromUtf8Error)

An error occurred converting to UTF-8 text.



Base64Decoder(DecodeError)

An error occurred decoding base-64 data.



Unknown(String)

An unknown error occurred.