GraphName

Enum GraphName 

pub enum GraphName {
    BNode(BlankNode),
    Iri(Iri),
}
This type denotes the identifier for a graph in a data set; a graph name MUST be either an Iri or a blank node.

Variants



BNode(BlankNode)



Iri(Iri)

Implementations

Source

impl GraphName

pub fn blank() -> Self

Construct a new graph name, as a blank node with a randomly assigned name.

pub fn blank_named<S>(name: S) -> Result<Self, Error>
where S: AsRef<str>,

Construct a new graph name, as a blank node with the specified name.

pub fn named(name: Iri) -> Self

Construct a new graph name, with an Iri naming a resource.

pub fn is_blank(&self) -> bool

Return true if this graph name is a blank node, else false.

pub fn as_blank(&self) -> Option<&BlankNode>

Return a blank node string, if self.is_blank(), else None.

pub fn is_iri(&self) -> bool

Return true if this graph name is an Iri, else false.

pub fn as_iri(&self) -> Option<&Iri>

Return a named node Iri, if self.is_iri(), else None.