Graph

Struct Graph 

pub struct Graph { /* private fields */ }
A graph is an unordered list of statements and may include duplicates. Note that this trait represents an immutable graph, a type should also implement the MutableGraph trait for mutation.

Implementations

Source

impl Graph

pub fn named<N>(name: N) -> Self
where N: Into<GraphName>,

pub fn unique() -> Self

pub fn unique_named<N>(name: N) -> Self
where N: Into<GraphName>,

pub fn with_mappings(self, mappings: IriPrefixMap) -> Self

pub fn with_statements(self, statements: Vec<Statement>) -> Self

pub fn is_empty(&self) -> bool

Returns true if there are no statements in this graph, else false.

pub fn len(&self) -> usize

Return the number of statements in this graph.

pub fn is_named(&self) -> bool

Returns true if this graph instance has a name.

pub fn name(&self) -> Option<&GraphName>

Return the name of this graph.

pub fn set_name(&mut self, name: GraphName)

Set the name of this graph.

pub fn unset_name(&mut self)

Remove the name of this graph.

pub fn contains_subject(&self, subject: &SubjectNode) -> bool

Returns true if this graph contains any statement with the provided subject, else false.

pub fn contains(&self, statement: &Statement) -> bool

Returns true if this graph contains the provided statement, else false.

pub fn contains_all( &self, subject: &SubjectNode, predicate: &Iri, object: &ObjectNode, ) -> bool

Returns true if this graph contains the any statement with the provided subject, predicate, and object, else false.

pub fn matches( &self, subject: Option<&SubjectNode>, predicate: Option<&Iri>, object: Option<&ObjectNode>, ) -> HashSet<&Statement>

Returns true if this graph contains the any statement with the provided subject, predicate, and object, else false.

pub fn statements(&self) -> impl Iterator<Item = &Statement>

Return an iterator over all the statements in the graph.

pub fn subjects(&self) -> HashSet<&SubjectNode>

Return a set of all subjects in the graph, note that this is a set so that it removes duplicates.

pub fn node_subjects(&self) -> HashSet<&SubjectNode>

Return a set of all subjects that are not blank nodes

pub fn blank_node_subjects(&self) -> HashSet<&SubjectNode>

Return a set of all subjects that are blank nodes

pub fn predicates(&self) -> HashSet<&Iri>

Return a set of all predicate in the graph, note that this is a set so that it removes duplicates.

pub fn predicates_for(&self, subject: &SubjectNode) -> HashSet<&Iri>

Return a set of all predicate referenced by the provided subject in graph, note that this is a set so that it removes duplicates.

pub fn objects(&self) -> HashSet<&ObjectNode>

Return a set of all objects in the graph, note that this is a set so that it removes duplicates.

pub fn objects_for( &self, subject: &SubjectNode, predicate: &Iri, ) -> HashSet<&ObjectNode>

Return a set of all objects referenced by the provided subject and predicate in the graph, note that this is a set so that it removes duplicates.

pub fn prefix_mappings(&self) -> &IriPrefixMap

Returns the set of prefix mappings held by the graph.

pub fn set_prefix_mappings(&mut self, mappings: IriPrefixMap)

Set the prefix mappings held by the graph.

pub fn insert(&mut self, statement: Statement)

Insert a new statement into the graph.

pub fn extend<I>(&mut self, iter: I)
where I: IntoIterator<Item = Statement>,

pub fn merge(&mut self, other: &Self)

Merge another graph into this one. Note that the graphs are required to have the same implementation type based in the type qualifiers for StatementIter.

pub fn dedup(&mut self) -> Vec<Statement>

Remove any duplicates within the graph, replacing any number of identical statements with just one. This will return a list of all statements removed.

This method does nothing if this graph has does not support the feature FEATURE_GRAPH_DUPLICATES and will therefore always return an empty list.

pub fn remove(&mut self, statement: &Statement)

Remove any statement that matches the provided. If a graph has duplicates this method does not differentiate between them.

pub fn remove_all_for(&mut self, subject: &SubjectNode) -> Vec<Statement>

Remove all statements from this graph that have the provided subject.

pub fn clear(&mut self)

Remove all statements from this graph.

pub fn skolemize(&self, base: &Iri) -> Result<Self, Error>

Return a new graph replacing all blank nodes with new, unique Iris. The base Iri is used to create identifiers, it’s path will be replaced entirely by a well-known format.

For example, given the following input graph with blank nodes:

<https://example.org/p/me> <https://example.org/v/name> _:B0f21 .
_:B0f21 <https://example.org/v/firstName> "My" .
_:B0f21 <https://example.org/v/lastName> "Name" .

the call to skolemize,

let base = Iri::from_str("https://example.com/me").unwrap();
graph.skolemize(&base)

results in a new graph containing replacement IRIs.

<https://example.org/p/me>
  <https://example.org/v/name>
  <https://example.com/.well-known/genid/62D22842-0D24-4911-AE7D-DF4DE06FD62F> .
<https://example.com/.well-known/genid/62D22842-0D24-4911-AE7D-DF4DE06FD62F>
  <https://example.org/v/firstName>
  "My" .
<https://example.com/.well-known/genid/62D22842-0D24-4911-AE7D-DF4DE06FD62F>
  <https://example.org/v/lastName>
  "Name" .
pub fn simplify(&self) -> Result<Self, Error>

Return a new graph with certain features flattened to simplify the graph to a strict triple structure. For example:

  1. RDF* statements in subject and object nodes are reified into the graph.
  2. RDF collection objects in object nodes are reified into the graph.