pub enum GraphName {
BNode(BlankNode),
Iri(Iri),
}Expand description
This type denotes the identifier for a graph in a data set; a graph name MUST be either an Iri or a blank node.
Variants
Implementations
Sourceimpl GraphName
impl GraphName
Sourcepub fn blank() -> Self
pub fn blank() -> Self
Construct a new graph name, as a blank node with a randomly assigned name.
Sourcepub fn blank_named<S>(name: S) -> Result<Self, Error>
pub fn blank_named<S>(name: S) -> Result<Self, Error>
Construct a new graph name, as a blank node with the specified name.